@@ -1,7 +1,7 @@
 /*
     ipv4.h -- missing IPv4 related definitions
-    Copyright (C) 2003 Ivo Timmermans <ivo@o2w.nl>
-                  2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 2004 Ivo Timmermans <ivo@tinc-vpn.org>
+                  2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: ipv4.h,v 1.1.2.4 2003/10/08 11:34:55 guus Exp $
+    $Id: ipv4.h 1412 2004-11-10 21:14:08Z guus $
 */
 
 #ifndef __TINC_IPV4_H__
@@ -35,6 +35,10 @@
 #define ICMP_DEST_UNREACH 3
 #endif
 
+#ifndef ICMP_FRAG_NEEDED
+#define ICMP_FRAG_NEEDED 4
+#endif
+
 #ifndef ICMP_NET_UNKNOWN
 #define ICMP_NET_UNKNOWN 6
 #endif
@@ -63,7 +67,6 @@ struct ip {
 #define IP_RF 0x8000
 #define IP_DF 0x4000
 #define IP_MF 0x2000
-#define IP_OFFMASK 0x1fff
 	uint8_t ip_ttl;
 	uint8_t ip_p;
 	uint16_t ip_sum;
@@ -71,6 +74,10 @@ struct ip {
 } __attribute__ ((__packed__));
 #endif
 
+#ifndef IP_OFFMASK
+#define IP_OFFMASK 0x1fff
+#endif
+
 #ifndef HAVE_STRUCT_ICMP
 struct icmp {
 	uint8_t icmp_type;
