@@ -1,7 +1,7 @@
 /*
     ipv6.h -- missing IPv6 related definitions
-    Copyright (C) 2003 Ivo Timmermans <ivo@o2w.nl>
-                  2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 2004 Ivo Timmermans <ivo@tinc-vpn.org>
+                  2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: ipv6.h,v 1.1.2.8 2003/11/08 15:09:03 guus Exp $
+    $Id: ipv6.h 1374 2004-03-21 14:21:22Z guus $
 */
 
 #ifndef __TINC_IPV6_H__
@@ -96,12 +96,14 @@ struct icmp6_hdr {
 } __attribute__ ((__packed__));
 #define ICMP6_DST_UNREACH_NOROUTE 0
 #define ICMP6_DST_UNREACH 1
+#define ICMP6_PACKET_TOO_BIG 2
 #define ICMP6_DST_UNREACH_ADDR 3
 #define ND_NEIGHBOR_SOLICIT 135
 #define ND_NEIGHBOR_ADVERT 136
 #define icmp6_data32 icmp6_dataun.icmp6_un_data32
 #define icmp6_data16 icmp6_dataun.icmp6_un_data16
 #define icmp6_data8 icmp6_dataun.icmp6_un_data8
+#define icmp6_mtu icmp6_data32[0]
 #endif
 
 #ifndef HAVE_STRUCT_ND_NEIGHBOR_SOLICIT
