@@ -1,8 +1,8 @@
 /*
     conf.c -- configuration code
     Copyright (C) 1998 Robert van der Meulen
-                  1998-2003 Ivo Timmermans <ivo@o2w.nl>
-                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>
+                  1998-2004 Ivo Timmermans <ivo@tinc-vpn.org>
+                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
 		  2000 Cris van Pelt <tribbel@arise.dhs.org>
 
     This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: conf.c,v 1.9.4.76 2003/08/28 21:05:10 guus Exp $
+    $Id: conf.c 1374 2004-03-21 14:21:22Z guus $
 */
 
 #include "system.h"
@@ -214,16 +214,14 @@ bool get_config_address(const config_t *cfg, struct addrinfo **result)
 
 bool get_config_subnet(const config_t *cfg, subnet_t ** result)
 {
-	subnet_t *subnet;
+	subnet_t subnet = {0};
 
 	cp();
 
 	if(!cfg)
 		return false;
 
-	subnet = str2net(cfg->value);
-
-	if(!subnet) {
+	if(!str2net(&subnet, cfg->value)) {
 		logger(LOG_ERR, _("Subnet expected for configuration variable %s in %s line %d"),
 			   cfg->variable, cfg->file, cfg->line);
 		return false;
@@ -231,17 +229,16 @@ bool get_config_subnet(const config_t *cfg, subnet_t ** result)
 
 	/* Teach newbies what subnets are... */
 
-	if(((subnet->type == SUBNET_IPV4)
-		&& !maskcheck(&subnet->net.ipv4.address, subnet->net.ipv4.prefixlength, sizeof(ipv4_t)))
-		|| ((subnet->type == SUBNET_IPV6)
-		&& !maskcheck(&subnet->net.ipv6.address, subnet->net.ipv6.prefixlength, sizeof(ipv6_t)))) {
+	if(((subnet.type == SUBNET_IPV4)
+		&& !maskcheck(&subnet.net.ipv4.address, subnet.net.ipv4.prefixlength, sizeof(ipv4_t)))
+		|| ((subnet.type == SUBNET_IPV6)
+		&& !maskcheck(&subnet.net.ipv6.address, subnet.net.ipv6.prefixlength, sizeof(ipv6_t)))) {
 		logger(LOG_ERR, _ ("Network address and prefix length do not match for configuration variable %s in %s line %d"),
 			   cfg->variable, cfg->file, cfg->line);
-		free(subnet);
 		return false;
 	}
 
-	*result = subnet;
+	*(*result = new_subnet()) = subnet;
 
 	return true;
 }
@@ -324,7 +321,7 @@ int read_config_file(avl_tree_t *config_tree, const char *fname)
 	int err = -2;				/* Parse error */
 	FILE *fp;
 	char *buffer, *line;
-	char *variable, *value;
+	char *variable, *value, *eol;
 	int lineno = 0;
 	int len;
 	bool ignore = false;
@@ -375,6 +372,10 @@ int read_config_file(avl_tree_t *config_tree, const char *fname)
 
 		variable = value = line;
 
+		eol = line + strlen(line);
+		while(strchr("\t ", *--eol))
+			*eol = '\0';
+
 		len = strcspn(value, "\t =");
 		value += len;
 		value += strspn(value, "\t ");
@@ -384,6 +385,7 @@ int read_config_file(avl_tree_t *config_tree, const char *fname)
 		}
 		variable[len] = '\0';
 
+	
 		if(!*value) {
 			logger(LOG_ERR, _("No value for variable `%s' on line %d while reading config file %s"),
 				   variable, lineno, fname);
