@@ -1,7 +1,7 @@
 /*
     connection.c -- connection list management
-    Copyright (C) 2000-2003 Guus Sliepen <guus@sliepen.eu.org>,
-                  2000-2003 Ivo Timmermans <ivo@o2w.nl>
+    Copyright (C) 2000-2004 Guus Sliepen <guus@tinc-vpn.org>,
+                  2000-2004 Ivo Timmermans <ivo@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: connection.c,v 1.1.2.44 2003/08/28 21:05:10 guus Exp $
+    $Id: connection.c 1374 2004-03-21 14:21:22Z guus $
 */
 
 #include "system.h"
