@@ -1,7 +1,7 @@
 /*
     net.h -- generic header for device.c
-    Copyright (C) 2001-2003 Ivo Timmermans <zarq@iname.com>
-                  2001-2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 2001-2004 Ivo Timmermans <zarq@iname.com>
+                  2001-2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: device.h,v 1.1.2.11 2003/07/22 20:55:19 guus Exp $
+    $Id: device.h 1374 2004-03-21 14:21:22Z guus $
 */
 
 #ifndef __TINC_DEVICE_H__
