@@ -1,7 +1,7 @@
 /*
     graph.c -- graph algorithms
-    Copyright (C) 2001-2003 Guus Sliepen <guus@sliepen.eu.org>,
-                  2001-2003 Ivo Timmermans <ivo@o2w.nl>
+    Copyright (C) 2001-2004 Guus Sliepen <guus@tinc-vpn.org>,
+                  2001-2004 Ivo Timmermans <ivo@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: graph.c,v 1.1.2.30 2003/10/10 16:23:30 guus Exp $
+    $Id: graph.c 1374 2004-03-21 14:21:22Z guus $
 */
 
 /* We need to generate two trees from the graph:
@@ -229,6 +229,14 @@ void sssp_bfs(void)
 
 					e->to->hostname = sockaddr2hostname(&e->to->address);
 					avl_insert_node(node_udp_tree, node);
+
+					if(e->to->options & OPTION_PMTU_DISCOVERY) {
+						e->to->mtuprobes = 0;
+						e->to->minmtu = 0;
+						e->to->maxmtu = MTU;
+						if(e->to->status.validkey)
+							send_mtu_probe(e->to);
+					}
 				}
 
 				node = avl_alloc_node();
@@ -262,6 +270,10 @@ void sssp_bfs(void)
 			n->status.validkey = false;
 			n->status.waitingforkey = false;
 
+			n->maxmtu = MTU;
+			n->minmtu = 0;
+			n->mtuprobes = 0;
+
 			asprintf(&envp[0], "NETNAME=%s", netname ? : "");
 			asprintf(&envp[1], "DEVICE=%s", device ? : "");
 			asprintf(&envp[2], "INTERFACE=%s", iface ? : "");
