@@ -1,7 +1,7 @@
 /*
     device.c -- Interaction with Linux ethertap and tun/tap device
-    Copyright (C) 2001-2003 Ivo Timmermans <ivo@o2w.nl>,
-                  2001-2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 2001-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2001-2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: device.c,v 1.1.2.21 2003/08/28 21:05:11 guus Exp $
+    $Id: device.c 1400 2004-11-01 17:02:19Z guus $
 */
 
 #include "system.h"
@@ -46,14 +46,14 @@ typedef enum device_type_t {
 } device_type_t;
 
 int device_fd = -1;
-device_type_t device_type;
+static device_type_t device_type;
 char *device;
 char *iface;
 char ifrname[IFNAMSIZ];
 char *device_info;
 
-int device_total_in = 0;
-int device_total_out = 0;
+static int device_total_in = 0;
+static int device_total_out = 0;
 
 bool setup_device(void)
 {
