@@ -1,7 +1,7 @@
 /*
     logger.c -- logging code
-    Copyright (C) 2003 Guus Sliepen <guus@sliepen.eu.org>
-                  2003 Ivo Timmermans <ivo@o2w.nl>
+    Copyright (C) 2004 Guus Sliepen <guus@tinc-vpn.org>
+                  2004 Ivo Timmermans <ivo@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: logger.c,v 1.1.2.12 2003/10/06 16:13:07 guus Exp $
+    $Id: logger.c 1374 2004-03-21 14:21:22Z guus $
 */
 
 #include "system.h"
