@@ -1,7 +1,7 @@
 /*
     meta.c -- handle the meta communication
-    Copyright (C) 2000-2003 Guus Sliepen <guus@sliepen.eu.org>,
-                  2000-2003 Ivo Timmermans <ivo@o2w.nl>
+    Copyright (C) 2000-2004 Guus Sliepen <guus@tinc-vpn.org>,
+                  2000-2004 Ivo Timmermans <ivo@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: meta.c,v 1.1.2.48 2003/10/12 11:40:00 guus Exp $
+    $Id: meta.c 1391 2004-09-20 20:56:14Z guus $
 */
 
 #include "system.h"
@@ -31,7 +31,6 @@
 #include "meta.h"
 #include "net.h"
 #include "protocol.h"
-#include "system.h"
 #include "utils.h"
 
 bool send_meta(connection_t *c, const char *buffer, int length)
