@@ -1,7 +1,7 @@
 /*
     meta.h -- header for meta.c
-    Copyright (C) 2000-2003 Guus Sliepen <guus@sliepen.eu.org>,
-                  2000-2003 Ivo Timmermans <ivo@o2w.nl>
+    Copyright (C) 2000-2004 Guus Sliepen <guus@tinc-vpn.org>,
+                  2000-2004 Ivo Timmermans <ivo@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: meta.h,v 1.1.2.11 2003/08/12 14:48:13 guus Exp $
+    $Id: meta.h 1374 2004-03-21 14:21:22Z guus $
 */
 
 #ifndef __TINC_META_H__
