@@ -1,7 +1,7 @@
 /*
     net.c -- most of the network code
-    Copyright (C) 1998-2003 Ivo Timmermans <ivo@o2w.nl>,
-                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 1998-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: net.c,v 1.35.4.200 2003/08/28 21:05:10 guus Exp $
+    $Id: net.c 1387 2004-06-21 14:37:52Z guus $
 */
 
 #include "system.h"
@@ -72,14 +72,16 @@ static void purge(void)
 			for(snode = n->subnet_tree->head; snode; snode = snext) {
 				snext = snode->next;
 				s = snode->data;
-				send_del_subnet(broadcast, s);
+				if(!tunnelserver)
+					send_del_subnet(broadcast, s);
 				subnet_del(n, s);
 			}
 
 			for(enode = n->edge_tree->head; enode; enode = enext) {
 				enext = enode->next;
 				e = enode->data;
-				send_del_edge(broadcast, e);
+				if(!tunnelserver)
+					send_del_edge(broadcast, e);
 				edge_del(e);
 			}
 		}
@@ -178,7 +180,7 @@ void terminate_connection(connection_t *c, bool report)
 		closesocket(c->socket);
 
 	if(c->edge) {
-		if(report)
+		if(report && !tunnelserver)
 			send_del_edge(broadcast, c->edge);
 
 		edge_del(c->edge);
@@ -193,7 +195,8 @@ void terminate_connection(connection_t *c, bool report)
 			edge_t *e;
 			e = lookup_edge(c->node, myself);
 			if(e) {
-				send_del_edge(broadcast, e);
+				if(!tunnelserver)
+					send_del_edge(broadcast, e);
 				edge_del(e);
 			}
 		}
@@ -245,7 +248,13 @@ static void check_dead_connections(void)
 				}
 				ifdebug(CONNECTIONS) logger(LOG_WARNING, _("Timeout from %s (%s) during authentication"),
 						   c->name, c->hostname);
-				terminate_connection(c, false);
+				if(c->status.connecting) {
+					c->status.connecting = false;
+					closesocket(c->socket);
+					do_outgoing_connection(c);
+				} else {
+					terminate_connection(c, false);
+				}
 			}
 		}
 	}
@@ -267,7 +276,7 @@ static void check_network_activity(fd_set * f)
 
 	if(FD_ISSET(device_fd, f)) {
 		if(read_packet(&packet))
-			route_outgoing(&packet);
+			route(myself, &packet);
 	}
 
 	for(node = connection_tree->head; node; node = node->next) {
@@ -331,7 +340,8 @@ int main_loop(void)
 	while(running) {
 		now = time(NULL);
 
-		tv.tv_sec = 1 + (rand() & 7);	/* Approx. 5 seconds, randomized to prevent global synchronisation effects */
+	//	tv.tv_sec = 1 + (rand() & 7);	/* Approx. 5 seconds, randomized to prevent global synchronisation effects */
+		tv.tv_sec = 1;
 		tv.tv_usec = 0;
 
 		maxfd = build_fdset(&fset);
@@ -364,7 +374,7 @@ int main_loop(void)
 			last_ping_check = now;
 
 			if(routing_mode == RMODE_SWITCH)
-				age_mac();
+				age_subnets();
 
 			age_past_requests();
 
