@@ -1,7 +1,7 @@
 /*
     net_socket.c -- Handle various kinds of sockets.
-    Copyright (C) 1998-2003 Ivo Timmermans <ivo@o2w.nl>,
-                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 1998-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: net_socket.c,v 1.1.2.34 2003/10/06 14:41:45 guus Exp $
+    $Id: net_socket.c 1413 2004-11-10 21:56:31Z guus $
 */
 
 #include "system.h"
@@ -41,6 +41,7 @@
 int addressfamily = AF_UNSPEC;
 int maxtimeout = 900;
 int seconds_till_retry = 5;
+bool blockingtcp = false;
 
 listen_socket_t listen_socket[MAXSOCKETS];
 int listen_sockets;
@@ -49,13 +50,10 @@ int listen_sockets;
 
 int setup_listen_socket(const sockaddr_t *sa)
 {
-	int nfd, flags;
+	int nfd;
 	char *addrstr;
 	int option;
 	char *iface;
-#ifdef SO_BINDTODEVICE
-	struct ifreq ifr;
-#endif
 
 	cp();
 
@@ -67,13 +65,15 @@ int setup_listen_socket(const sockaddr_t *sa)
 	}
 
 #ifdef O_NONBLOCK
-	flags = fcntl(nfd, F_GETFL);
+	{
+		int flags = fcntl(nfd, F_GETFL);
 
-	if(fcntl(nfd, F_SETFL, flags | O_NONBLOCK) < 0) {
-		closesocket(nfd);
-		logger(LOG_ERR, _("System call `%s' failed: %s"), "fcntl",
-			   strerror(errno));
-		return -1;
+		if(fcntl(nfd, F_SETFL, flags | O_NONBLOCK) < 0) {
+			closesocket(nfd);
+			logger(LOG_ERR, _("System call `%s' failed: %s"), "fcntl",
+				   strerror(errno));
+			return -1;
+		}
 	}
 #endif
 
@@ -94,6 +94,8 @@ int setup_listen_socket(const sockaddr_t *sa)
 	if(get_config_string
 	   (lookup_config(config_tree, "BindToInterface"), &iface)) {
 #if defined(SOL_SOCKET) && defined(SO_BINDTODEVICE)
+		struct ifreq ifr;
+
 		memset(&ifr, 0, sizeof(ifr));
 		strncpy(ifr.ifr_ifrn.ifrn_name, iface, IFNAMSIZ);
 
@@ -129,13 +131,9 @@ int setup_listen_socket(const sockaddr_t *sa)
 
 int setup_vpn_in_socket(const sockaddr_t *sa)
 {
-	int nfd, flags;
+	int nfd;
 	char *addrstr;
 	int option;
-#if defined(SOL_SOCKET) && defined(SO_BINDTODEVICE)
-	char *iface;
-	struct ifreq ifr;
-#endif
 
 	cp();
 
@@ -147,29 +145,58 @@ int setup_vpn_in_socket(const sockaddr_t *sa)
 	}
 
 #ifdef O_NONBLOCK
-	flags = fcntl(nfd, F_GETFL);
-	if(fcntl(nfd, F_SETFL, flags | O_NONBLOCK) < 0) {
-		closesocket(nfd);
-		logger(LOG_ERR, _("System call `%s' failed: %s"), "fcntl",
-			   strerror(errno));
-		return -1;
+	{
+		int flags = fcntl(nfd, F_GETFL);
+
+		if(fcntl(nfd, F_SETFL, flags | O_NONBLOCK) < 0) {
+			closesocket(nfd);
+			logger(LOG_ERR, _("System call `%s' failed: %s"), "fcntl",
+				   strerror(errno));
+			return -1;
+		}
 	}
 #endif
 
 	option = 1;
 	setsockopt(nfd, SOL_SOCKET, SO_REUSEADDR, &option, sizeof(option));
 
-#if defined(SOL_SOCKET) && defined(SO_BINDTODEVICE)
-	if(get_config_string
-	   (lookup_config(config_tree, "BindToInterface"), &iface)) {
-		memset(&ifr, 0, sizeof(ifr));
-		strncpy(ifr.ifr_ifrn.ifrn_name, iface, IFNAMSIZ);
+#if defined(SOL_IP) && defined(IP_MTU_DISCOVER) && defined(IP_PMTUDISC_DO)
+	{
+		bool choice;
 
-		if(setsockopt(nfd, SOL_SOCKET, SO_BINDTODEVICE, &ifr, sizeof(ifr))) {
-			closesocket(nfd);
-			logger(LOG_ERR, _("Can't bind to interface %s: %s"), iface,
-				   strerror(errno));
-			return -1;
+		if(get_config_bool(lookup_config(myself->connection->config_tree, "PMTUDiscovery"), &choice) && choice) {
+			option = IP_PMTUDISC_DO;
+			setsockopt(nfd, SOL_IP, IP_MTU_DISCOVER, &option, sizeof(option));
+		}
+	}
+#endif
+
+#if defined(SOL_IPV6) && defined(IPV6_MTU_DISCOVER) && defined(IPV6_PMTUDISC_DO)
+	{
+		bool choice;
+
+		if(get_config_bool(lookup_config(myself->connection->config_tree, "PMTUDiscovery"), &choice) && choice) {
+			option = IPV6_PMTUDISC_DO;
+			setsockopt(nfd, SOL_IPV6, IPV6_MTU_DISCOVER, &option, sizeof(option));
+		}
+	}
+#endif
+
+#if defined(SOL_SOCKET) && defined(SO_BINDTODEVICE)
+	{
+		char *iface;
+		struct ifreq ifr;
+
+		if(get_config_string(lookup_config(config_tree, "BindToInterface"), &iface)) {
+			memset(&ifr, 0, sizeof(ifr));
+			strncpy(ifr.ifr_ifrn.ifrn_name, iface, IFNAMSIZ);
+
+			if(setsockopt(nfd, SOL_SOCKET, SO_BINDTODEVICE, &ifr, sizeof(ifr))) {
+				closesocket(nfd);
+				logger(LOG_ERR, _("Can't bind to interface %s: %s"), iface,
+					   strerror(errno));
+				return -1;
+			}
 		}
 	}
 #endif
@@ -214,6 +241,16 @@ void finish_connecting(connection_t *c)
 
 	ifdebug(CONNECTIONS) logger(LOG_INFO, _("Connected to %s (%s)"), c->name, c->hostname);
 
+#ifdef O_NONBLOCK
+	if(blockingtcp) {
+		int flags = fcntl(c->socket, F_GETFL);
+
+		if(fcntl(c->socket, F_SETFL, flags & ~O_NONBLOCK) < 0) {
+			logger(LOG_ERR, _("fcntl for %s: %s"), c->hostname, strerror(errno));
+		}
+	}
+#endif
+
 	c->last_ping_time = now;
 
 	send_id(c);
@@ -255,8 +292,7 @@ begin:
 		goto begin;
 	}
 
-	memcpy(&c->address, c->outgoing->aip->ai_addr,
-		   c->outgoing->aip->ai_addrlen);
+	memcpy(&c->address, c->outgoing->aip->ai_addr, c->outgoing->aip->ai_addrlen);
 	c->outgoing->aip = c->outgoing->aip->ai_next;
 
 	if(c->hostname)
@@ -400,6 +436,16 @@ bool handle_new_meta_connection(int sock)
 
 	ifdebug(CONNECTIONS) logger(LOG_NOTICE, _("Connection from %s"), c->hostname);
 
+#ifdef O_NONBLOCK
+	if(blockingtcp) {
+		int flags = fcntl(c->socket, F_GETFL);
+
+		if(fcntl(c->socket, F_SETFL, flags & ~O_NONBLOCK) < 0) {
+			logger(LOG_ERR, _("fcntl for %s: %s"), c->hostname, strerror(errno));
+		}
+	}
+#endif
+
 	connection_add(c);
 
 	c->allow_request = ID;
