@@ -1,7 +1,7 @@
 /*
     netutl.h -- header file for netutl.c
-    Copyright (C) 1998-2003 Ivo Timmermans <zarq@iname.com>
-                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 1998-2004 Ivo Timmermans <zarq@iname.com>
+                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: netutl.h,v 1.2.4.19 2003/08/22 11:18:42 guus Exp $
+    $Id: netutl.h 1374 2004-03-21 14:21:22Z guus $
 */
 
 #ifndef __TINC_NETUTL_H__
