@@ -1,7 +1,7 @@
 /*
     node.c -- node tree management
-    Copyright (C) 2001-2003 Guus Sliepen <guus@sliepen.eu.org>,
-                  2001-2003 Ivo Timmermans <ivo@o2w.nl>
+    Copyright (C) 2001-2004 Guus Sliepen <guus@tinc-vpn.org>,
+                  2001-2004 Ivo Timmermans <ivo@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: node.c,v 1.1.2.28 2003/08/28 21:05:10 guus Exp $
+    $Id: node.c 1374 2004-03-21 14:21:22Z guus $
 */
 
 #include "system.h"
@@ -80,6 +80,8 @@ node_t *new_node(void)
 	n->edge_tree = new_edge_tree();
 	n->queue = list_alloc((list_action_t) free);
 	EVP_CIPHER_CTX_init(&n->packet_ctx);
+	n->mtu = MTU;
+	n->maxmtu = MTU;
 
 	return n;
 }
@@ -109,6 +111,9 @@ void free_node(node_t *n)
 	sockaddrfree(&n->address);
 
 	EVP_CIPHER_CTX_cleanup(&n->packet_ctx);
+
+	if(n->mtuevent)
+		event_del(n->mtuevent);
 	
 	free(n);
 }
@@ -179,11 +184,11 @@ void dump_nodes(void)
 
 	for(node = node_tree->head; node; node = node->next) {
 		n = node->data;
-		logger(LOG_DEBUG, _(" %s at %s cipher %d digest %d maclength %d compression %d options %lx status %04x nexthop %s via %s"),
+		logger(LOG_DEBUG, _(" %s at %s cipher %d digest %d maclength %d compression %d options %lx status %04x nexthop %s via %s pmtu %d (min %d max %d)"),
 			   n->name, n->hostname, n->cipher ? n->cipher->nid : 0,
 			   n->digest ? n->digest->type : 0, n->maclength, n->compression,
 			   n->options, *(uint32_t *)&n->status, n->nexthop ? n->nexthop->name : "-",
-			   n->via ? n->via->name : "-");
+			   n->via ? n->via->name : "-", n->mtu, n->minmtu, n->maxmtu);
 	}
 
 	logger(LOG_DEBUG, _("End of nodes."));
