@@ -1,7 +1,7 @@
 /*
     node.h -- header for node.c
-    Copyright (C) 2001-2003 Guus Sliepen <guus@sliepen.eu.org>,
-                  2001-2003 Ivo Timmermans <ivo@o2w.nl>
+    Copyright (C) 2001-2004 Guus Sliepen <guus@tinc-vpn.org>,
+                  2001-2004 Ivo Timmermans <ivo@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: node.h,v 1.1.2.29 2003/07/30 21:52:41 guus Exp $
+    $Id: node.h 1374 2004-03-21 14:21:22Z guus $
 */
 
 #ifndef __TINC_NODE_H__
@@ -25,13 +25,14 @@
 
 #include "avl_tree.h"
 #include "connection.h"
+#include "event.h"
 #include "list.h"
 #include "subnet.h"
 
 typedef struct node_status_t {
 	int active:1;				/* 1 if active.. */
 	int validkey:1;				/* 1 if we currently have a valid key for him */
-	int waitingforkey:1;		/* 1 if we already sent out a request */
+	int waitingforkey:1;			/* 1 if we already sent out a request */
 	int visited:1;				/* 1 if this node has been visited by one of the graph algorithms */
 	int reachable:1;			/* 1 if this node is reachable in the graph */
 	int indirect:1;				/* 1 if this node is not directly reachable by us */
@@ -39,7 +40,7 @@ typedef struct node_status_t {
 } node_status_t;
 
 typedef struct node_t {
-	char *name;					/* name of this node */
+	char *name;				/* name of this node */
 	long int options;			/* options turned on for this node */
 
 	sockaddr_t address;			/* his real (internet) ip to send UDP packets to */
@@ -47,30 +48,36 @@ typedef struct node_t {
 
 	node_status_t status;
 
-	const EVP_CIPHER *cipher;	/* Cipher type for UDP packets */
-	char *key;					/* Cipher key and iv */
+	const EVP_CIPHER *cipher;		/* Cipher type for UDP packets */
+	char *key;				/* Cipher key and iv */
 	int keylength;				/* Cipher key and iv length */
-	EVP_CIPHER_CTX packet_ctx;	/* Cipher context */
+	EVP_CIPHER_CTX packet_ctx;		/* Cipher context */
 	
-	const EVP_MD *digest;		/* Digest type for MAC */
+	const EVP_MD *digest;			/* Digest type for MAC */
 	int maclength;				/* Length of MAC */
 
 	int compression;			/* Compressionlevel, 0 = no compression */
 
 	list_t *queue;				/* Queue for packets awaiting to be encrypted */
 
-	struct node_t *nexthop;		/* nearest node from us to him */
+	struct node_t *nexthop;			/* nearest node from us to him */
 	struct node_t *via;			/* next hop for UDP packets */
 
-	avl_tree_t *subnet_tree;	/* Pointer to a tree of subnets belonging to this node */
+	avl_tree_t *subnet_tree;		/* Pointer to a tree of subnets belonging to this node */
 
-	avl_tree_t *edge_tree;		/* Edges with this node as one of the endpoints */
+	avl_tree_t *edge_tree;			/* Edges with this node as one of the endpoints */
 
 	struct connection_t *connection;	/* Connection associated with this node (if a direct connection exists) */
 
-	uint32_t sent_seqno;		/* Sequence number last sent to this node */
-	uint32_t received_seqno;	/* Sequence number last received from this node */
-	unsigned char late[16];	/* Bitfield marking late packets */
+	uint32_t sent_seqno;			/* Sequence number last sent to this node */
+	uint32_t received_seqno;		/* Sequence number last received from this node */
+	unsigned char late[16];			/* Bitfield marking late packets */
+
+	length_t mtu;				/* Maximum size of packets to send to this node */
+	length_t minmtu;			/* Probed minimum MTU */
+	length_t maxmtu;			/* Probed maximum MTU */
+	int mtuprobes;				/* Number of probes */
+	event_t *mtuevent;			/* Probe event */
 } node_t;
 
 extern struct node_t *myself;
