@@ -1,7 +1,7 @@
 /*
     process.c -- process management functions
-    Copyright (C) 1999-2003 Ivo Timmermans <ivo@o2w.nl>,
-                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 1999-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: process.c,v 1.1.2.76 2003/10/06 16:13:08 guus Exp $
+    $Id: process.c 1397 2004-11-01 15:18:22Z guus $
 */
 
 #include "system.h"
@@ -104,7 +104,7 @@ bool install_service(void) {
 
 	service = CreateService(manager, identname, identname,
 			SERVICE_ALL_ACCESS, SERVICE_WIN32_OWN_PROCESS, SERVICE_AUTO_START, SERVICE_ERROR_NORMAL,
-			command, "NDIS", NULL, NULL, NULL, NULL);
+			command, NULL, NULL, NULL, NULL, NULL);
 	
 	if(!service) {
 		logger(LOG_ERR, _("Could not create %s service: %s"), identname, winerror(GetLastError()));
@@ -257,8 +257,10 @@ static bool write_pidfile(void)
 	}
 
 	/* if it's locked, write-protected, or whatever */
-	if(!write_pid(pidfilename))
+	if(!write_pid(pidfilename)) {
+		fprintf(stderr, _("Could write pid file %s: %s\n"), pidfilename, strerror(errno));
 		return false;
+	}
 
 	return true;
 }
@@ -335,8 +337,10 @@ bool detach(void)
 
 		/* Now UPDATE the pid in the pidfile, because we changed it... */
 
-		if(!write_pid(pidfilename))
+		if(!write_pid(pidfilename)) {
+			fprintf(stderr, _("Could not write pid file %s: %s\n"), pidfilename, strerror(errno));
 			return false;
+		}
 #else
 		if(!statushandle)
 			exit(install_service());
@@ -358,7 +362,8 @@ bool execute_script(const char *name, char **envp)
 #ifdef HAVE_SYSTEM
 	int status, len;
 	struct stat s;
-	char *scriptname;
+	char *scriptname, *p;
+	int i;
 
 	cp();
 
@@ -382,8 +387,8 @@ bool execute_script(const char *name, char **envp)
 #ifdef HAVE_PUTENV
 	/* Set environment */
 	
-	while(*envp)
-		putenv(*envp++);
+	for(i = 0; envp[i]; i++)
+		putenv(envp[i]);
 #endif
 
 	scriptname[len - 1] = '\"';
@@ -391,7 +396,17 @@ bool execute_script(const char *name, char **envp)
 
 	free(scriptname);
 
-	/* Unset environment? */
+	/* Unset environment */
+
+	for(i = 0; envp[i]; i++) {
+		char *e = strchr(envp[i], '=');
+		if(e) {
+			p = alloca(e - envp[i] + 1);
+			strncpy(p, envp[i], e - envp[i]);
+			p[e - envp[i]] = '\0';
+			putenv(p);
+		}
+	}
 
 #ifdef WEXITSTATUS
 	if(status != -1) {
@@ -427,13 +442,19 @@ bool execute_script(const char *name, char **envp)
 static RETSIGTYPE sigterm_handler(int a)
 {
 	logger(LOG_NOTICE, _("Got %s signal"), "TERM");
-	running = false;
+	if(running)
+		running = false;
+	else
+		exit(1);
 }
 
 static RETSIGTYPE sigquit_handler(int a)
 {
 	logger(LOG_NOTICE, _("Got %s signal"), "QUIT");
-	running = false;
+	if(running)
+		running = false;
+	else
+		exit(1);
 }
 
 static RETSIGTYPE fatal_signal_square(int a)
