@@ -1,7 +1,7 @@
 /*
     protocol_auth.c -- handle the meta-protocol, authentication
-    Copyright (C) 1999-2003 Ivo Timmermans <ivo@o2w.nl>,
-                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 1999-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: protocol_auth.c,v 1.1.4.28 2003/10/11 12:28:48 guus Exp $
+    $Id: protocol_auth.c 1374 2004-03-21 14:21:22Z guus $
 */
 
 #include "system.h"
@@ -51,7 +51,6 @@ bool send_id(connection_t *c)
 bool id_h(connection_t *c)
 {
 	char name[MAX_STRING_SIZE];
-	bool choice;
 
 	cp();
 
@@ -109,14 +108,6 @@ bool id_h(connection_t *c)
 		return false;
 	}
 
-	/* Check some options */
-
-	if((get_config_bool(lookup_config(c->config_tree, "IndirectData"), &choice) && choice) || myself->options & OPTION_INDIRECT)
-		c->options |= OPTION_INDIRECT;
-
-	if((get_config_bool(lookup_config(c->config_tree, "TCPOnly"), &choice) && choice) || myself->options & OPTION_TCPONLY)
-		c->options |= OPTION_TCPONLY | OPTION_INDIRECT;
-
 	c->allow_request = METAKEY;
 
 	return send_metakey(c);
@@ -468,6 +459,7 @@ bool send_ack(connection_t *c)
 	   to create node_t and edge_t structures. */
 
 	struct timeval now;
+	bool choice;
 
 	cp();
 
@@ -476,6 +468,19 @@ bool send_ack(connection_t *c)
 	gettimeofday(&now, NULL);
 	c->estimated_weight = (now.tv_sec - c->start.tv_sec) * 1000 + (now.tv_usec - c->start.tv_usec) / 1000;
 
+	/* Check some options */
+
+	if((get_config_bool(lookup_config(c->config_tree, "IndirectData"), &choice) && choice) || myself->options & OPTION_INDIRECT)
+		c->options |= OPTION_INDIRECT;
+
+	if((get_config_bool(lookup_config(c->config_tree, "TCPOnly"), &choice) && choice) || myself->options & OPTION_TCPONLY)
+		c->options |= OPTION_TCPONLY | OPTION_INDIRECT;
+
+	if((get_config_bool(lookup_config(c->config_tree, "PMTUDiscovery"), &choice) && choice) || myself->options & OPTION_PMTU_DISCOVERY)
+		c->options |= OPTION_PMTU_DISCOVERY;
+
+	get_config_int(lookup_config(c->config_tree, "Weight"), &c->estimated_weight);
+
 	return send_request(c, "%d %s %d %lx", ACK, myport, c->estimated_weight, c->options);
 }
 
@@ -488,6 +493,15 @@ static void send_everything(connection_t *c)
 
 	/* Send all known subnets and edges */
 
+	if(tunnelserver) {
+		for(node = myself->subnet_tree->head; node; node = node->next) {
+			s = node->data;
+			send_add_subnet(c, s);
+		}
+
+		return;
+	}
+
 	for(node = node_tree->head; node; node = node->next) {
 		n = node->data;
 
@@ -507,7 +521,7 @@ bool ack_h(connection_t *c)
 {
 	char hisport[MAX_STRING_SIZE];
 	char *hisaddress, *dummy;
-	int weight;
+	int weight, mtu;
 	long int options;
 	node_t *n;
 
@@ -542,6 +556,12 @@ bool ack_h(connection_t *c)
 	c->node = n;
 	c->options |= options;
 
+	if(get_config_int(lookup_config(c->config_tree, "PMTU"), &mtu) && mtu < n->mtu)
+		n->mtu = mtu;
+
+	if(get_config_int(lookup_config(myself->connection->config_tree, "PMTU"), &mtu) && mtu < n->mtu)
+		n->mtu = mtu;
+
 	/* Activate this connection */
 
 	c->allow_request = ALL;
@@ -572,7 +592,10 @@ bool ack_h(connection_t *c)
 
 	/* Notify everyone of the new edge */
 
-	send_add_edge(broadcast, c->edge);
+	if(tunnelserver)
+		send_add_edge(c, c->edge);
+	else
+		send_add_edge(broadcast, c->edge);
 
 	/* Run MST and SSSP algorithms */
 
