@@ -1,7 +1,7 @@
 /*
     protocol_edge.c -- handle the meta-protocol, edges
-    Copyright (C) 1999-2003 Ivo Timmermans <ivo@o2w.nl>,
-                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>
+    Copyright (C) 1999-2004 Ivo Timmermans <ivo@tinc-vpn.org>,
+                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: protocol_edge.c,v 1.1.4.21 2003/08/28 15:27:12 guus Exp $
+    $Id: protocol_edge.c 1374 2004-03-21 14:21:22Z guus $
 */
 
 #include "system.h"
@@ -110,6 +110,9 @@ bool add_edge_h(connection_t *c)
 		node_add(to);
 	}
 
+	if(tunnelserver && from != myself && from != c->node && to != myself && to != c->node)
+		return false;
+
 	/* Convert addresses */
 
 	address = str2sockaddr(to_address, to_port);
@@ -154,7 +157,8 @@ bool add_edge_h(connection_t *c)
 
 	/* Tell the rest about the new edge */
 
-	forward_request(c);
+	if(!tunnelserver)
+		forward_request(c);
 
 	/* Run MST before or after we tell the rest? */
 
@@ -221,6 +225,9 @@ bool del_edge_h(connection_t *c)
 		return true;
 	}
 
+	if(tunnelserver && from != myself && from != c->node && to != myself && to != c->node)
+		return false;
+
 	/* Check if edge exists */
 
 	e = lookup_edge(from, to);
@@ -240,7 +247,8 @@ bool del_edge_h(connection_t *c)
 
 	/* Tell the rest about the deleted edge */
 
-	forward_request(c);
+	if(!tunnelserver)
+		forward_request(c);
 
 	/* Delete the edge */
 
@@ -255,7 +263,8 @@ bool del_edge_h(connection_t *c)
 	if(!to->status.reachable) {
 		e = lookup_edge(to, myself);
 		if(e) {
-			send_del_edge(broadcast, e);
+			if(!tunnelserver)
+				send_del_edge(broadcast, e);
 			edge_del(e);
 		}
 	}
