@@ -1,7 +1,7 @@
 /*
     route.h -- header file for route.c
-    Copyright (C) 2000-2003 Ivo Timmermans <zarq@iname.com>
-                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>         
+    Copyright (C) 2000-2004 Ivo Timmermans <zarq@iname.com>
+                  2000-2004 Guus Sliepen <guus@tinc-vpn.org>         
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: route.h,v 1.1.2.13 2003/07/22 20:55:20 guus Exp $
+    $Id: route.h 1374 2004-03-21 14:21:22Z guus $
 */
 
 #ifndef __TINC_ROUTE_H__
@@ -39,8 +39,7 @@ extern int macexpire;
 
 extern mac_t mymac;
 
-extern void age_mac(void);
-extern void route_incoming(struct node_t *, struct vpn_packet_t *);
-extern void route_outgoing(struct vpn_packet_t *);
+extern void age_subnets(void);
+extern void route(struct node_t *, struct vpn_packet_t *);
 
 #endif							/* __TINC_ROUTE_H__ */
