@@ -1,7 +1,7 @@
 /*
     subnet.h -- header for subnet.c
-    Copyright (C) 2000,2001 Guus Sliepen <guus@sliepen.eu.org>,
-                  2000,2001 Ivo Timmermans <ivo@o2w.nl>
+    Copyright (C) 2000-2004 Guus Sliepen <guus@tinc-vpn.org>,
+                  2000-2004 Ivo Timmermans <ivo@tinc-vpn.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: subnet.h,v 1.1.2.25 2003/10/06 14:33:04 guus Exp $
+    $Id: subnet.h 1374 2004-03-21 14:21:22Z guus $
 */
 
 #ifndef __TINC_SUBNET_H__
@@ -34,7 +34,6 @@ typedef enum subnet_type_t {
 
 typedef struct subnet_mac_t {
 	mac_t address;
-	time_t lastseen;
 } subnet_mac_t;
 
 typedef struct subnet_ipv4_t {
@@ -53,6 +52,7 @@ typedef struct subnet_t {
 	struct node_t *owner;		/* the owner of this subnet */
 
 	subnet_type_t type;		/* subnet type (IPv4? IPv6? MAC? something even weirder?) */
+	time_t expires;			/* expiry time */
 
 	/* And now for the actual subnet: */
 
@@ -63,6 +63,9 @@ typedef struct subnet_t {
 	} net;
 } subnet_t;
 
+#define MAXNETSTR 64
+
+extern int subnet_compare(const struct subnet_t *, const struct subnet_t *);
 extern subnet_t *new_subnet(void) __attribute__ ((__malloc__));
 extern void free_subnet(subnet_t *);
 extern void init_subnets(void);
@@ -71,8 +74,8 @@ extern avl_tree_t *new_subnet_tree(void) __attribute__ ((__malloc__));
 extern void free_subnet_tree(avl_tree_t *);
 extern void subnet_add(struct node_t *, subnet_t *);
 extern void subnet_del(struct node_t *, subnet_t *);
-extern char *net2str(const subnet_t *);
-extern subnet_t *str2net(const char *);
+extern bool net2str(char *, int, const subnet_t *);
+extern bool str2net(subnet_t *, const char *);
 extern subnet_t *lookup_subnet(const struct node_t *, const subnet_t *);
 extern subnet_t *lookup_subnet_mac(const mac_t *);
 extern subnet_t *lookup_subnet_ipv4(const ipv4_t *);
